Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1347)

Unified Diff: webkit/appcache/appcache_host.h

Issue 8949001: Fix some loose ends around recently introduced AppCache INTERCEPT namespaces (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 8 years, 12 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/appcache/appcache_host.h
===================================================================
--- webkit/appcache/appcache_host.h (revision 116156)
+++ webkit/appcache/appcache_host.h (working copy)
@@ -123,9 +123,9 @@
// Used to ensure that a loaded appcache survives a frame navigation.
void LoadMainResourceCache(int64 cache_id);
// Used to notify the host that a fallback resource is being delivered as
// the main resource of the page and to provide its url.
- void NotifyMainResourceFallback(const GURL& fallback_url);
+ void NotifyMainResourceIsNamespaceEntry(const GURL& namespace_entry_url);
// Used to notify the host that the main resource was blocked by a policy. To
// work properly, this method needs to by invoked prior to cache selection.
@@ -245,9 +245,10 @@
SwapCacheCallback pending_swap_cache_callback_;
void* pending_callback_param_;
- // True if a fallback resource was delivered as the main resource.
- bool main_resource_was_fallback_;
- GURL fallback_url_;
+ // True if an intercept or fallback namespace resource was
+ // delivered as the main resource.
+ bool main_resource_was_namespace_entry_;
+ GURL namespace_entry_url_;
// True if requests for this host were blocked by a policy.
bool main_resource_blocked_;
@@ -123,9 +123,9 @@
// Used to ensure that a loaded appcache survives a frame navigation.
void LoadMainResourceCache(int64 cache_id);
- // Used to notify the host that a fallback resource is being delivered as
+ // Used to notify the host that a namespace resource is being delivered as
// the main resource of the page and to provide its url.

Powered by Google App Engine
This is Rietveld 408576698